@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2016-2018 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2016-2020 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda::Repository;
-$Qgoda::Repository::VERSION = '0.9.7';
+$Qgoda::Repository::VERSION = '0.9.8';
 use strict;
 
 use Locale::TextDomain qw(qgoda);
@@ -147,32 +147,26 @@ sub fetch {
     return ($dir, $tmp);
 }
 
-package URI::git;
-$URI::git::VERSION = '0.9.7';
-use strict;
-
-use base qw(URI::http);
-
 package URI::git_Phttp;
-$URI::git_Phttp::VERSION = '0.9.7';
+$URI::git_Phttp::VERSION = '0.9.8';
 use strict;
 
 use base qw(URI::git);
 
 package URI::git_Phttps;
-$URI::git_Phttps::VERSION = '0.9.7';
+$URI::git_Phttps::VERSION = '0.9.8';
 use strict;
 
 use base qw(URI::git);
 
 package URI::git_Pssh;
-$URI::git_Pssh::VERSION = '0.9.7';
+$URI::git_Pssh::VERSION = '0.9.8';
 use strict;
 
 use base qw(URI::git);
 
 package URI::git_Pfile;
-$URI::git_Pfile::VERSION = '0.9.7';
+$URI::git_Pfile::VERSION = '0.9.8';
 use strict;
 
 use base qw(URI::file);
